function P=ctod(xi,fn)
% CTOD  Converts a second order continuous time polynomial in terms of
%	damping factor and the natural frequency to a second order 
%	polynomial in z-1.
%
%	P=ctod(xi,fn)
%
%	xi: is the damping factor. 
%	fn: is the normalized frequency (fn=f/fs,where f is the natural 
%	frequency in Hz and fs is the sampling frequency). It should
%	be mentioned that fn is between 0 and 0.5.
%	
%	P: is a monic polynomial in z-1
% 
% June 30,1999
% Copyright by Adaptech, 1997-1999

if nargin~=2, error('usage: P=ctod(xi,fn)');end

w0=2*pi*fn;
a1=-2*exp(-1*xi*w0)*cos(w0*sqrt(1-xi*xi));
a2=exp(-2*xi*w0);

P=[1 a1 a2];